/* eslint-disable react/no-danger */
/* eslint-disable react/prop-types */
/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import PropTypes from 'prop-types';
import ReviewLink from 'gatsby-core-theme/src/components/atoms/review-link';
// import Tnc from 'gatsby-core-theme/src/components/molecules/tnc';
import Bonus from '~molecules/bonus-box/template-one';
import SellingPoints from '~atoms/selling-points';
import StarRating from '~molecules/star-rating/one-star';
import OperatorCta from '~atoms/button/operator-cta';
import { prettyTracker, imagePrettyUrl, getAltText } from '~helpers/getters';
import LazyImage from '~hooks/lazy-image';
import verify from '../../../../../images/verify.svg';

import styles from './default-row.module.scss';

const Row = ({
  item,
  oneliner = 'main',
  layout = 'list',
  tracker = 'main',
  pageTemplate,
  itemRefs,
  index,
  className,
}) => {
  const prettyLink = prettyTracker(item, 'main', false, pageTemplate);
  const itemRating = item.rating;
  const reviewPath = item.review_link ? `${item.review_link}` : item.path || null;
  const imageObject = item?.standardised_logo_url_object || item?.logo_url_object;

  const addToRefs = (el, itemNum) => {
    if (el && itemRefs) {
      itemRefs.current[itemNum] = el;
    }
  };

  const tandcEnabled =
    item?.extra_fields?.terms_and_conditions_text_enabled === '1' &&
    item?.extra_fields?.terms_and_conditions;

  const authorObject = item?.authorImageObject;

  return (
    <li
      className={`${className} ${styles.row} ${styles[layout]}`}
      ref={(el) => addToRefs(el, index)}
    >
      <div className={styles.ribbons}>
        {item.ribbons && item.ribbons.map((ribbon) => <span>{ribbon}</span>)}
      </div>
      <div className={styles.logo}>
        <a
          href={prettyLink}
          title={item.name}
          className="casinos-top-list-gtm logo-cta"
          target="_blank"
          rel="noreferrer"
          aria-label={`${item.name} Link`}
        >
          <LazyImage
            alt={getAltText(imageObject, item.name)}
            src={imagePrettyUrl(imageObject?.filename || item?.logo_url, 96, 96)}
            width={96}
            height={96}
          />
        </a>
        <div>
          <p>{item.name}</p>
          <div className={styles.ratingAuthor}>
            <StarRating numOfStars={5} rating={itemRating} />
            {authorObject && (
              <div>
                <LazyImage
                  alt={getAltText(authorObject, authorObject.alt)}
                  src={imagePrettyUrl(authorObject?.filename, 30, 30)}
                  width={30}
                  height={30}
                />
                <LazyImage src={verify} alt="verify" width={10} height={10} />
              </div>
            )}
          </div>
          {reviewPath && <ReviewLink reviewPath={reviewPath} operatorName={item?.name} />}
        </div>
      </div>
      <SellingPoints sellingPoints={item.selling_points} />
      <Bonus item={item} tracker={oneliner} />
      <OperatorCta
        operator={item}
        tracker={tracker}
        gtmClass="toplist-operator-cta-gtm"
        pageTemplate={pageTemplate}
      />

      {tandcEnabled && (
        <span
          className={styles.tnc}
          dangerouslySetInnerHTML={{
            __html: item?.extra_fields?.terms_and_conditions,
          }}
        />
      )}
    </li>
  );
};

Row.propTypes = {
  oneliner: PropTypes.string,
  layout: PropTypes.string,
  tracker: PropTypes.string,
  item: PropTypes.shape({
    name: PropTypes.string,
    ribbons: PropTypes.arrayOf(PropTypes.string),
    logo_url: PropTypes.string,
    selling_points: PropTypes.arrayOf(PropTypes.string),
    review_link: PropTypes.string,
    rating: PropTypes.string,
    one_liners: PropTypes.shape({
      main: PropTypes.shape({
        one_liner: PropTypes.string,
      }),
    }),
    logo_url_object: PropTypes.shape({
      filename: PropTypes.string,
    }),
    standardised_logo_url_object: PropTypes.shape({
      filename: PropTypes.string,
    }),
    bonus: PropTypes.oneOfType([PropTypes.array, PropTypes.object]),
  }).isRequired,
  pageTemplate: PropTypes.string,
};

export default Row;
